#
# spec file for package perl-Digest-MD5
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Digest-MD5
Name:           perl-Digest-MD5
Version:        2.590.0
Release:        2.4
%define cpan_version 2.59
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl interface to the MD-5 algorithm
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Digest::MD5) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The 'Digest::MD5' module allows you to use the RSA Data Security Inc. MD5
Message Digest algorithm from within Perl programs. The algorithm takes as
input a message of arbitrary length and produces as output a 128-bit
"fingerprint" or "message digest" of the input.

Note that the MD5 algorithm is not as strong as it used to be. It has since
2005 been easy to generate different messages that produce the same MD5
digest. It still seems hard to generate messages that produce a given
digest, but it is probably wise to move to stronger algorithms for
applications that depend on the digest to uniquely identify a message.

The 'Digest::MD5' module provide a procedural interface for simple use, as
well as an object oriented interface that can handle messages of arbitrary
length and which can read files directly.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README rfc1321.txt

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Sun Dec 31 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.59
  see /usr/share/doc/packages/perl-Digest-MD5/Changes
  2.59 Sat Dec 30 2023
  - Remove meaningless const type qualifier to silence HPUX builds.
  - remove useless perl 5.6 check
  - convert bits.t test to use Test::More
  - Update Digest::MD5 Synopsis and Examples. Add `my` to synopsis
  - MD5.xs: eliminate C++ guards
* Tue Oct  6 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.58
  see /usr/share/doc/packages/perl-Digest-MD5/Changes
  2.58 Mon Oct 5 2020
  - Update repo location.
  - Update recent changelog entries. Let's see if that's enough to make metacpan happy.
  2.57 Mon Oct 5 2020
  - Merge change submitted to blead - https://github.com/Perl/perl5/commit/ee9ac1cd8eb988fea70841eae211b11355711416
  2.56 Mon Oct 5 2020
  - Github CI Perl 5.6..5.32
  - Fixup MANIFEST/MANIFEST.SKIP/.gitignore
  - Enable strict and warnings on all code. Drop vars.pm - https://github.com/Dual-Life/digest-md5/pull/11
  - Preserve OPTIMIZE in hints/irix_6.pl - https://github.com/Dual-Life/digest-md5/pull/14
  - Don't return context buffer if there isn't one - https://github.com/Dual-Life/digest-md5/pull/12
  - Silence possible loss of data warnings on Win32 - https://github.com/Dual-Life/digest-md5/pull/13
  2.55 Wed Mar 9 2016
* Fri Mar 11 2016 coolo@suse.com
- updated to 2.55
  see /usr/share/doc/packages/perl-Digest-MD5/Changes
  2016-03-09   Gisle Aas <gisle@ActiveState.com>
    Release 2.55
    Gordon Stanton (2):
    Make use warnings work including test cases.
    Initial Travis config
    Gisle Aas (1):
    Avoid warning: 'static' is not at beginning of declaration [RT#105646]
* Mon Apr 13 2015 coolo@suse.com
- updated to 2.54
  see /usr/share/doc/packages/perl-Digest-MD5/Changes
  2015-01-12   Gisle Aas <gisle@ActiveState.com>
    Release 2.54
    David Mitchell: silence some compiler warnings
    Jonathan Hall: Add ->context() feature
    Steve Hay: Sync with blead
    bulk88: const the vtable
    zefram: 5.6 threads test fix
* Fri Nov 22 2013 herbert@graeber-clan.de
- upgrade to v2.53
* Mon Jan 14 2013 Greg.Freemyer@gmail.com
- upgrade to v2.52
  * Digest::Perl::MD5 OO fallback didn't work [RT#66634]
  * Modernize the code in the POD.
  * Makes Digest::MD5 work on Perl 5.6 [RT#75032]
  Release 2.51
  * Fix compilation with c++ compilers
  * Fix repository specification in META.yml
  Release 2.50
  * Amended tests to work with perl core.
  * Attach context pointers using sv magic
  * Add failing test for thread cloning
  * Clone MD5 contexts on thread cloning
  * get_md5_ctx should never return anything but a valid pointer
  * perl-5.6 no longer supported
  * Preserve utf8ness of argument [RT#44927]
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Sep  6 2010 chris@computersalat.de
- recreated by cpanspec 1.78
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- update to 2.40:
  * safer alignment test [RT#35823]
  * consting in new ext/
- changes from 2.39:
  * get rid of the PERL_CORE hacks
  * ext/Digest/MD5 to ext/Digest-MD5
- changes from 2.38:
  * applied warning fix [RT#19643]
  * applied compatiblity fix [RT#30348]
- changes from 2.37:
  * sync up with consting changes from the perl core
* Tue Sep 12 2006 James Oakley <jfunk@funktronics.ca>
- Initial release (2.36)
